@@ -84,9 +84,7 @@ if (debug) Rprintf("normal?f %i\n",normal);
   else lforward[0]=data[0]*log(mu[0])-mu[0]-lgamma(data[0]+1);} else{
      lforward[0]=lprob[0];
   }
-//  for (int j=1; j<J; j++) lforward[n*j]=-INF;
   if (verbose) Rprintf("\nCalculating forward matrix...\n");     
-//  int a=0;
   for (int i=1; i<n; i++) {
     if (verbose) {
       if ((i+1)%10000==0)   Rprintf(".");
@@ -122,15 +120,9 @@ void backward(double* data, double* lbackward, double* lforward, double* lprob,
   double aux1=-0.5*log(2*M_PI);
   double aux2=-0.5;
   double priortemp1;
- // double aux3=log(0.5);
-
- // bool upper;    
   if (debug) Rprintf("normal?b %i\n",normal);
  for (int j=0; j<J; j++) for (int i=0; i<n; i++) lbackward[n*j+i]=-INF;
-
-//  int a=J-2;
   lbackward[n*J-1]=0.0;
-//  for (int j=0; j<(J-1); j++) lbackward[n*j+n-1]=-INF;
   if (verbose) Rprintf("\nCalculating backward matrix...\n");      
   for (int i=n-2; i>=0; i--) {
    if (verbose) {
@@ -211,7 +203,7 @@ if (debug) Rprintf("normal? %i\n",normal);
         if (priortype==3) priortemp=rprior[k];    
         lforward[n*nseg*j+n*k+i]=lforward[n*nseg*j+n*k+i-1]+log(1-priortemp);      
           for (int jj=0; jj<J; jj++) {
-             if (jj != j) lforward[n*nseg*j+n*k+i]=lsum(lforward[n*nseg*j+n*k+i],lforward[n*nseg*jj+n*(k-1)+i-1]+log(priortemp)-log(J-1));
+             if (jj != j) lforward[n*nseg*j+n*k+i]=lsum(lforward[n*nseg*j+n*k+i],lforward[n*nseg*jj+n*(k-1)+i-1]+log(priortemp)-log(J-1.0));
          }
         lforward[n*nseg*j+n*k+i]=lforward[n*nseg*j+n*k+i]+ldist[j];
       }
@@ -265,8 +257,8 @@ void backward_lev(double* data, double* lbackward, double* lforward, double* lpr
         lbackward[n*nseg*j+n*k+i]=lbackward[n*nseg*j+n*k+i+1]+ldist[j]+log(1-priortemp);
         for (int jj=J-1; jj>=0; jj--) {
           if (jj != j) {
-            lbackward[n*nseg*j+n*k+i]=lsum(lbackward[n*nseg*j+n*k+i],lbackward[n*nseg*jj+n*(k+1)+i+1]+ldist[jj]+log(priortemp1)-log(J-1)); 
-            cp[(n-1)*k+i]=cp[(n-1)*k+i]+exp(lforward[n*nseg*j+n*k+i]+lbackward[n*nseg*jj+n*(k+1)+i+1]+ldist[jj]+log(priortemp1)-log(J-1)-evidence1);
+            lbackward[n*nseg*j+n*k+i]=lsum(lbackward[n*nseg*j+n*k+i],lbackward[n*nseg*jj+n*(k+1)+i+1]+ldist[jj]+log(priortemp1)-log(J-1.0)); 
+            cp[(n-1)*k+i]=cp[(n-1)*k+i]+exp(lforward[n*nseg*j+n*k+i]+lbackward[n*nseg*jj+n*(k+1)+i+1]+ldist[jj]+log(priortemp1)-log(J-1.0)-evidence1);
           }
         }
       }
@@ -343,9 +335,9 @@ for (int r=0; r<nsamples; r++) {
          if (jj==0) rand=runif(0,1.0);
          if (jj!=j){ 
           if (!probs){      
-  	  if (normal) aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1)+aux1+aux2*(data[i+1]-rmu[jj])*(data[i+1]-rmu[jj])/sigma);
-          else aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1)+data[i+1]*log(rmu[jj])-rmu[jj]-lgamma(data[i+1]+1));
-	  } else aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1)+lprob[n*jj+i+1]);
+  	  if (normal) aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1.0)+aux1+aux2*(data[i+1]-rmu[jj])*(data[i+1]-rmu[jj])/sigma);
+          else aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1.0)+data[i+1]*log(rmu[jj])-rmu[jj]-lgamma(data[i+1]+1));
+	  } else aux=aux+exp(rlbackward[n*nseg*jj+n*(k+1)+i+1]-rlbackward[n*nseg*j+n*k+i]+log(priortemp)-log(J-1.0)+lprob[n*jj+i+1]);
          } // jj!=j
    	 if (rand<aux){
            j=jj;
@@ -480,10 +472,8 @@ void viterbi_lev(double* data, double* lprob, double* bestcp, double* bestlevel,
 
 
   if (verbose) Rprintf("\nApplying Viterbi algorithm ...\n");      
-  //int  j=0;
   for (int k=0; k<nseg; k++) {vitstate[n*k]=0;
-vitlevel[n*k]=0;}
-//  int k=0;
+  vitlevel[n*k]=0;}
 
   for (int i=1; i<n; i++) {
      if (priortype==2) priortemp=rprior[i-1];
@@ -493,9 +483,6 @@ vitlevel[n*k]=0;}
        else ldist[0]=data[i]*log(mu[0])-mu[0]-lgamma(data[i]+1);} else{
             ldist[0]=lprob[i];
       }
-//   for (int j=0; j<J; j++)   
-//    vitstate[i]=vitstate[i-1];     
-    //  vitlevel[i]=vitlevel[i-1]; 
     if (verbose)   if ((i+1)%10000==0)  Rprintf("."); 
     for (int k=0;k<nseg;k++){ 
       // if (debug)Rprintf("%0.7f",ldist);
@@ -503,14 +490,11 @@ vitlevel[n*k]=0;}
        for (int j=0;j<J;j++){ 
          if (priortype==3) priortemp=rprior[0];
          maxvit=lviterbi[n*nseg*j+n*k+i-1]+log(1-priortemp);
-  //       change=false;
+
          vitstate[n*nseg*j+n*k+i]=k; 
          vitlevel[n*nseg*j+n*k+i]=j; 
          if (k>0){
-        
            if (priortype==3) priortemp=rprior[k-1];
-
-  //         changevit-INF; 
            for (int jj=0;jj<J;jj++){  
              if (jj!=j){  
                tempvit=lviterbi[n*nseg*jj+n*(k-1)+i-1]+log(priortemp); // log(J-1) penalizes changes too much               
@@ -518,7 +502,6 @@ vitlevel[n*k]=0;}
                  maxvit=tempvit;   
                  vitstate[n*nseg*j+n*k+i]=k-1; 
                  vitlevel[n*nseg*j+n*k+i]=jj; 
-             //    change=true;
                  lastlevel=jj;
                }
              }             
